"""Top-level package for igel."""
from .igel import Igel, models_dict, metrics_dict


__author__ = "Nidhal Baccouri"
__email__ = 'nidhalbacc@gmail.com'
__version__ = '0.1.9'
